@@ -69,8 +69,9 @@ Example:
 """
 
 import struct
+from binascii import unhexlify
 
-from Crypto.Util.py3compat import bord, unhexlify, _copy_bytes
+from Crypto.Util.py3compat import bord, _copy_bytes
 from Crypto.Util.number import long_to_bytes, bytes_to_long
 from Crypto.Util.strxor import strxor
 
@@ -518,7 +519,7 @@ def _create_ocb_cipher(factory, **kwargs):
         if nonce is None:
             nonce = get_random_bytes(15)
         mac_len = kwargs.pop("mac_len", 16)
-    except KeyError, e:
+    except KeyError as e:
         raise TypeError("Keyword missing: " + str(e))
 
     return OcbMode(factory, nonce, mac_len, kwargs)
